# Track data

Use the LaminDB instance to track your local files, cloud files or even in-memory objects via {class}`~lamindb.File`.

**Jump to:**

- {doc}`/guide/files`
- {doc}`/guide/memory`
- {doc}`/guide/existing`
- {doc}`/guide/folder`
- {doc}`/guide/file`

```{toctree}
:hidden:
:maxdepth: 1

files
memory
existing
folder
file
```
